The result is a data frame with a summary of the statistics obtained:
meanUmean of the U dataset.
meanVmean of the V dataset.
RMSEroot mean square error between U and V.
sdUxstandard deviation of zonal component (U).
sdUystandard deviation of meridional component (U).
sdVxstandard deviation of zonal component (V).
sdVystandard deviation of meridional component (V).
EuEOF matrix for the U dataset.
EvEOF matrix for the V dataset.
Sigmaumatrix with standard deviations of U (2x2 matrix).
Sigmavmatrix with standard deviations of V (2x2 matrix).
TotVarUtotal variance of the U dataset.
TotVarVtotal variance of the V dataset.
thetauangle of EOF1 (U) with zonal axis.
thetavangle of EOF1 (V) with meridional axis.
thetavurotation angle from U EOFs to V EOFs.
R2vecvector correlation squared in 2D as defined by Breaker, Gemmill and Crossby (1994).
Rvurotation matrix to express Ev as a rotation from Eu.
EccentricityUeccentricity of the ellipses from the reference dataset.
EccentricityVeccentricity of the ellipses from the model dataset.
congruenceEOFcongruence coefficients (absolute value) for EOFs.